$ErrorActionPreference  = 'Stop';

# Make sure to kill any presencelight processes before attempting an
# installation. This covers the case that PresenceLight is currently
# installed outside of Chocolatey
Get-Process presencelight* -ErrorAction SilentlyContinue | Stop-Process

$WindowsVersion=[Environment]::OSVersion.Version
if ($WindowsVersion.Major -ne "10") {
  throw "This package requires Windows 10."
}

$IsCorrectBuild=[Environment]::OSVersion.Version.Build
if ($IsCorrectBuild -lt "17134") {
  throw "This package requires at least Windows 10 version build 17134.x."
}

$packageName    = "presencelight"
$toolsDir       = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$InstallDir     = Join-Path $env:APPDATA 'PresenceLight'

$pp = Get-PackageParameters

if($pp['InstallDir']){
  $InstallDir = $pp['InstallDir']
}

$packageArgs = @{
  packageName    = $packageName
  unzipLocation  = $InstallDir
  urlARM         = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.4.1/PresenceLight.5.4.1-win-arm64.zip"
  url86bit       = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.4.1/PresenceLight.5.4.1-x86.zip"
  url64bit       = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.4.1/PresenceLight.5.4.1-x64.zip"
  checksumARM    = "ED491A3B42E1E7B821C242D5E24C4DED4BCFB52425C5946CD6345DB31C9A5C13"
  checksum       = "3AB068F943FCA9711063F255A8189C83B132FB70858D06BBDB9B1B573B79B0CD"
  checksum64     = "EFA21A024EFB41A9B5F145DD5F7852070D3940FEABF9FC1ED864318F6C816479"
  checksumType   = 'SHA256'
}

Install-ChocolateyZipPackage @packageArgs

$exePath = Join-Path $InstallDir 'PresenceLight.exe'


Write-Output "Adding shortcut to Start Menu"
Install-ChocolateyShortcut -ShortcutFilePath "C:\ProgramData\Microsoft\Windows\Start Menu\Programs\PresenceLight.lnk" -TargetPath $exePath -WorkingDirectory $InstallDir

Write-Output "Adding shortcut to Startup"
Install-ChocolateyShortcut -ShortcutFilePath "C:\ProgramData\Microsoft\Windows\Start Menu\Programs\Startup\PresenceLight.lnk" -TargetPath $exePath -WorkingDirectory $InstallDir

